@@ -1,6 +1,9 @@
 import keyMirror from 'keymirror';
 
 export default keyMirror({
+  FETCH_RESOURCES_PENDING: null,
+  FETCH_RESOURCES_SUCCESS: null,
+  FETCH_RESOURCES_FAILED: null,
   FETCH_STACKS_PENDING: null,
   FETCH_STACKS_SUCCESS: null,
   FETCH_STACKS_FAILED: null
